/* **********************************************************************
*   File: email.c					   Mercury 2.0b *
*  Usage: Email command for in-game characters.				*
*									*
*  Based on original concept by: Brad Carps (Oberon) <leam@euridia.com> *
*  Developed for Euridia by: Shane P. Lee (Fire)			*
*  Copyright 2000 Shane P. Lee <tacodog21@yahoo.com>			*									*
*********************************************************************** */

#include "conf.h"
#include "sysdep.h"

#include "structs.h"
#include "utils.h"
#include "comm.h"
#include "interpreter.h"
#include "db.h"
#include "boards.h"
#include "genolc.h"
#include "oasis.h"
#include "improved-edit.h"


/* ---------------------------------------------------------------------- */

void email_setup_new(struct descriptor_data *d)
{
  /* If you chose to add GET_EMAIL, uncomment this:
  char *ebuf[MAX_INPUT_LENGTH];
   */

  CREATE(OLC_EMAIL(d), struct email_data, 1);

  /* If you chose to add GET_EMAIL, use this instead:
  sprintf(ebuf, GET_EMAIL(d->character));
  OLC_EMAIL(d)->from = ebuf;
   */
  OLC_EMAIL(d)->from = str_dup("Nobody"); /* If you added GET_EMAIL, delete this line altogether! */
  OLC_EMAIL(d)->target = str_dup("Unknown");
  OLC_EMAIL(d)->subject = str_dup("Nothing.");
  OLC_EMAIL(d)->body = str_dup("This message is blank.");
  email_disp_menu(d);
  OLC_VAL(d) = 0;
}

/* ---------------------------------------------------------------------- */

#define SENDMAIL "/usr/bin/sendmail"
/* Make sure this ^^^^^^^^^^^^^^^^^ points to your version of sendmail */

void email_save_to_disk(struct descriptor_data *d)
{
   FILE *fp;
   static char foot_buf[MAX_INPUT_LENGTH];

      /* write the message footnote */
      /* Feel free to edit this for your mud */
      sprintf(foot_buf, "\n\n\n"
"+------------------------------------------------------------------+------+\n"
"| Get your MUD on @ Euridia.com!                                   |  __  |\n"
"| http://www.euridia.com -- Your ultimate MUD resource             | (oO) |\n"
"| telnet://euridia.com:4545 -- Euridia MUD                         | /||\\ |\n"
"| telnet://euridia.com:4000 -- The E2K Project                     |      |\n"
"+------------------------------------------------------------------+------+\n");


    sprintf(buf, "%s %s", SENDMAIL, OLC_EMAIL(d)->target);
    fp = popen(buf, "w");
        fprintf(fp, "From: %s\n", OLC_EMAIL(d)->from);
        fprintf(fp, "To: %s\n", OLC_EMAIL(d)->target);
        /* If you chose to add GET_EMAIL, uncomment this:
        fprintf(fp, "Reply-To: %s\n", GET_EMAIL(d->character)); */
        /* Feel free to edit the following two fields */
        fprintf(fp, "X-Mailer: Euridia MUD Mailing System <http://www.euridia.com>\n");
        fprintf(fp, "Questions: This e-mail was sent by a player on our MUD.  For more info, please e-mail leam@euridia.com.\n");
        /* Feel free to edit the above two fields */
        fprintf(fp, "Subject: %s\n", OLC_EMAIL(d)->subject);
        fprintf(fp, "%s", OLC_EMAIL(d)->body);
        fprintf(fp, "%s", foot_buf);
        fprintf(fp, ".\n");
        pclose(fp);
      SEND_TO_Q("\r\nThank you for using the Mercury E-mail system!\r\n", d);
}

/* --------------------------- The main menu --------------------------- */

void email_disp_menu(struct descriptor_data *d)
{
  struct email_data *mail;

  get_char_colors(d->character);
  /* OasisOLCv2.0-pre12 users: use the following:
  clear_screen(d);
   * everyone else, use this: */
  clear_screen(d->character);
  mail = OLC_EMAIL(d);

  sprintf(buf,
	  "\r\n- Welcome to Mercury 2.0b -\r\n"
          /* Out of respect, please leave the following messages in. */
	  "Coded by: Fire\r\n"
	  "Concept by: Oberon\r\n"
	  "\r\n\r\n"
          /* Thank you :-) -spl */
	  "%sF)%s From        : %s%s\r\n"
	  "%sT)%s To          : %s%s\r\n"
	  "%sS)%s Subject     : %s%s\r\n"
	  "%sM)%s Message     : %s%s\r\n"
	  "%sQ%s) Quit\r\n"
	  "Enter choice : ",

	  grn, cyn, yel, mail->from,
	  grn, cyn, yel, mail->target,
	  grn, cyn, yel, mail->subject,
	  grn, cyn, yel, mail->body,
          grn, nrm
	  );
  SEND_TO_Q(buf, d);

  OLC_MODE(d) = EMAIL_MAIN_MENU;
}

/* ------------------------- The main loop ------------------------- */

void email_parse(struct descriptor_data *d, char *arg)
{
  char *oldtext = NULL;

  switch (OLC_MODE(d)) {
  case EMAIL_CONFIRM_SAVESTRING:
    switch (*arg) {
    case 'y':
    case 'Y':
      email_save_to_disk(d);
      cleanup_olc(d, CLEANUP_STRUCTS);
      break;
    case 'n':
    case 'N':
      cleanup_olc(d, CLEANUP_ALL);
      break;
    default:
      SEND_TO_Q("Invalid choice!\r\nDo you wish to send this email? : ", d);
      break;
    }
    return;

  case EMAIL_MAIN_MENU:
    switch (*arg) {
    case 'q':
    case 'Q':
      if (OLC_VAL(d)) { /* Something has been modified. */
	SEND_TO_Q("Do you wish to send this email? : ", d);
	OLC_MODE(d) = EMAIL_CONFIRM_SAVESTRING;
      } else
	cleanup_olc(d, CLEANUP_ALL);
      return;
    case 'f':
    case 'F':
      SEND_TO_Q("Enter the name you wish to appear on the From field:-\r\n] ", d);
      OLC_MODE(d) = EMAIL_FROM;
      OLC_VAL(d) = 1;
      break;
    case 't':
    case 'T':
      SEND_TO_Q("Enter address of recipient:-\r\n] ", d);
      OLC_MODE(d) = EMAIL_2WHO;
      OLC_VAL(d) = 1;
      break;
    case 's':
    case 'S':
      SEND_TO_Q("Enter the message subject:-\r\n]", d);
      OLC_MODE(d) = EMAIL_SUBJECT;
      OLC_VAL(d) = 1;
      break;
    case 'm':
    case 'M':
      OLC_MODE(d) = EMAIL_BODY;
      /* OasisOLCv2.0-pre12 users: use the following:
      clear_screen(d);
      * everyone else, use this: */
      clear_screen(d->character);
      send_editor_help(d);
      SEND_TO_Q("Edit the message below:\r\n\r\n", d);

      if (OLC_EMAIL(d)->body) {
	SEND_TO_Q(OLC_EMAIL(d)->body, d);
	oldtext = str_dup(OLC_EMAIL(d)->body);
      }
      string_write(d, &OLC_EMAIL(d)->body, MAX_STRING_LENGTH, 0, oldtext);
      OLC_VAL(d) = 1;
      break;
    default:
      SEND_TO_Q("Invalid choice!\r\n", d);
      /* Seems setting a descriptor's mode to the same
       * one as already exists crashes the game, so we
       * fake it out and set it different, so email_disp_menu
       * can set it all right again. -spl
      */
      OLC_MODE(d) = EMAIL_CONFIRM_SAVESTRING;
      email_disp_menu(d);
      break;
    }
    return;

  case EMAIL_FROM:
    if (!genolc_checkstring(d, arg))
      break;
    if (OLC_EMAIL(d)->from)
      free(OLC_EMAIL(d)->from);
    /* Let's use redit's built-in limiter here */
    arg[MAX_ROOM_NAME - 1] = '\0';
    OLC_EMAIL(d)->from = str_udup(arg);
    break;

  case EMAIL_2WHO:
    if (!genolc_checkstring(d, arg))
      break;
    if (OLC_EMAIL(d)->target)
      free(OLC_EMAIL(d)->target);
    /* Let's use redit's built-in limiter here */
    arg[MAX_ROOM_NAME - 1] = '\0';
    OLC_EMAIL(d)->target = str_udup(arg);
    break;

  case EMAIL_SUBJECT:
    if (!genolc_checkstring(d, arg))
      break;
    if (OLC_EMAIL(d)->subject)
      free(OLC_EMAIL(d)->subject);
    /* Let's use redit's built-in limiter again */
    arg[MAX_ROOM_NAME - 1] = '\0';
    OLC_EMAIL(d)->subject = str_udup(arg);
    break;

  case EMAIL_BODY:
    /*
     * We will NEVER get here, we hope.
     */
    mudlog("SYSERR: Reached EMAIL_BODY case in Mercury! Report this to Head Coder!", BRF, LVL_BUILDER, TRUE);
    break;

  default:
    /*
     * We should never get here.
     */
    mudlog("SYSERR: Reached default case in Mercury! Report this to Head Coder!", BRF, LVL_BUILDER, TRUE);
    break;
  }
  /*
   * If we get this far, something has been changed.
   */
  OLC_VAL(d) = 1;
  email_disp_menu(d);
}

void email_string_cleanup(struct descriptor_data *d, int terminator)
{
  switch (OLC_MODE(d)) {
  case EMAIL_BODY:
    email_disp_menu(d);
    break;
  }
}
